@@ -23,12 +23,10 @@ class DisplayInfo():
         return self.app
 
     def get_scale_factor(self, app):
-        # app = QApplication(sys.argv)
-        # app =1
         screens = app.screens()
         for i, screen in enumerate(screens):
             logical_dpi = screen.logicalDotsPerInch()
-            print(screen, logical_dpi)
+            # print(screen, logical_dpi)
             self.scale_factor.append(logical_dpi / 96.0)  # Based on Windows' standard DPI of 96
         #     # print(f"Monitor {i+1}: Scale Factor = {self.scale_factors}")
         return self.scale_factor
